@@ -4,8 +4,12 @@ from alembic import context
 from sqlalchemy import engine_from_config
 from sqlalchemy import pool
 
+from openmodule.checks import check_invalid_database_column_type
+from openmodule.database.custom_types import CustomType
+
 # this is the Alembic Config object, which provides
 # access to the values within the .ini file in use.
+
 config = context.config
 
 # Interpret the config file for Python logging.
@@ -16,6 +20,17 @@ if config.attributes.get('configure_logging', True):
 target_metadata = config.attributes["target_metadata"]
 
 
+def render_item(type_, obj, autogen_context):
+    """Apply custom rendering for selected items."""
+
+    check_invalid_database_column_type(obj)
+    custom_import, name = CustomType.custom_import(obj)
+    if type_ == 'type' and custom_import:
+        autogen_context.imports.add(f"from {custom_import} import {name}")
+        return "%r" % obj
+    return False
+
+
 def run_migrations_online():
     def process_revision_directives(context, revision, directives):
         if config.cmd_opts.autogenerate:
@@ -34,7 +49,8 @@ def run_migrations_online():
     with connectable.connect() as connection:
         context.configure(
             connection=connection, target_metadata=target_metadata,
-            process_revision_directives=process_revision_directives
+            process_revision_directives=process_revision_directives,
+            render_item=render_item,
         )
 
         with context.begin_transaction():
