@@ -3,7 +3,7 @@ from typing import Optional
 
 from pydantic import Field
 
-from openmodule.models.base import ZMQMessage, OpenModuleModel, Gateway
+from openmodule.models.base import ZMQMessage, OpenModuleModel, Gateway, timezone_validator
 from openmodule.models.vehicle import Medium, LPRMedium
 
 
@@ -23,15 +23,21 @@ class PresenceBaseMessage(ZMQMessage):
     gateway: Gateway
     medium: PresenceMedia
 
+    _tz_last_update = timezone_validator("last_update")
+
 
 class PresenceBackwardMessage(PresenceBaseMessage):
     type: str = "backward"
-    leave_time: str = Field(..., alias="leave-time")
+    leave_time: datetime = Field(..., alias="leave-time")
+
+    _tz_leave_time = timezone_validator("leave_time")
 
 
 class PresenceForwardMessage(PresenceBaseMessage):
     type: str = "forward"
-    leave_time: str = Field(..., alias="leave-time")
+    leave_time: datetime = Field(..., alias="leave-time")
+
+    _tz_leave_time = timezone_validator("leave_time")
 
 
 class PresenceLeaveMessage(PresenceBaseMessage):
