@@ -2,7 +2,7 @@ import random
 from datetime import datetime
 from typing import Optional, Callable
 
-from openmodule.models.base import Direction, Gateway
+from openmodule.models.base import Direction, Gateway, datetime_to_timestamp
 from openmodule.models.presence import PresenceBaseMessage, PresenceEnterMessage, PresenceLeaveMessage, \
     PresenceForwardMessage, PresenceBackwardMessage, PresenceMedia, PresenceChangeMessage
 from openmodule.models.vehicle import LPRMedium, LPRCountry, Medium, Vehicle
@@ -72,7 +72,7 @@ class PresenceSimulator:
         return VehicleBuilder()
 
     def _common_kwargs(self, vehicle):
-        timestamp = datetime.now().timestamp()
+        timestamp = datetime_to_timestamp(datetime.now())
         return {
             "vehicle_id": vehicle.vehicle_id,
             "unsure": False,
@@ -102,7 +102,7 @@ class PresenceSimulator:
             vehicle = self.leave()
         self.emit(PresenceForwardMessage(
             **self._common_kwargs(vehicle),
-            **{"leave-time": datetime.now().timestamp()}
+            **{"leave-time": datetime_to_timestamp(datetime.now())}
         ))
 
     def backward(self, vehicle: Optional[VehicleBuilder] = None):
@@ -111,7 +111,7 @@ class PresenceSimulator:
             vehicle = self.leave()
         self.emit(PresenceBackwardMessage(
             **self._common_kwargs(vehicle),
-            **{"leave-time": datetime.now().timestamp()}
+            **{"leave-time": datetime_to_timestamp(datetime.now())}
         ))
 
     def change(self, vehicle: VehicleBuilder):
@@ -120,7 +120,6 @@ class PresenceSimulator:
         self.current_present = vehicle
         self.emit(PresenceChangeMessage(
             **self._common_kwargs(vehicle),
-            **{"leave-time": datetime.now().timestamp()}
         ))
 
     def change_vehicle_and_id(self, vehicle: VehicleBuilder):
@@ -129,5 +128,5 @@ class PresenceSimulator:
         self.current_present = vehicle
         self.emit(PresenceChangeMessage(
             **self._common_kwargs(vehicle),
-            **{"leave-time": datetime.now().timestamp(), "change_vehicle_id": True}
+            change_vehicle_id=True
         ))
